#!/bin/bash
. /usr/share/idzor/setup/include.sh

# Initial setup, creating database for patchs + service file.
if [ "$APPDB" != "" ]
then
  echo "Creating initial database"
  /bin/bash $APPPATH/setup/install/create_database.sh
fi

# Copy initial config files
if [ "$APPCONFPATH" != "" ]
then
  mkdir -p $APPCONFPATH
  cp --recursive --force $APPPATH/setup/conf/* $APPCONFPATH/ 2> /dev/null
fi

# exec npm install if needed
if [ -f $APPPATH/bin/package.json ]
then
  echo "Installing NPM deps"
  OLDDIR=`pwd`
  cd $APPPATH/bin
  npm install
  cd $OLDDIR
fi

# Run patch
echo "Running patchs"
bash $APPPATH/setup/update/install_patchs.sh

if [ "$SERVICENAME" != "" ]
then
  echo "Creating service file"
  cat > /etc/systemd/system/$SERVICENAME.service <<-EOF
  [Unit]
  Description=$APPNAME service file
  Documentation=
  Wants=network-online.target
  After=

  [Service]
  User=root
  Type=simple
  ExecStart=$SERVICEEXECSTART
  ExecStop=$SERVICEEXECSTOP
  ExecReload=
  Restart=on-failure
  RestartSec=10
  WorkingDirectory=$APPPATH
  KillMode=control-group
  KillSignal=SIGKILL

  [Install]
  WantedBy=multi-user.target
EOF
  systemctl enable $SERVICENAME
  systemctl start $SERVICENAME
fi


touch $APPCONFPATH/idzor.lic
chmod 777 $APPCONFPATH/idzor.lic
chmod +x $APPPATH/bin/idzor.php

if [ -L /usr/sbin/idzor ]
then
  echo "Removing old binary link"
  unlink /usr/sbin/idzor
fi
echo "Creating binary link"
ln -s $APPPATH/bin/idzor.php /usr/sbin/idzor

if [ -e /etc/cron.d/idzor ]
then
  rm -f /etc/cron.d/idzor
fi

# Compatibility !!!
if [ -L $APPPATH/idzorlib.php ]
then
  unlink $APPPATH/idzorlib.php
fi
echo "Adding compatibility link"
ln -s $APPPATH/bin/idzorlib.php $APPPATH/idzorlib.php
